#!/bin/bash
#
## Script d'instal·lació de la Linkat
#

TMPDIR=$(/bin/mktemp -d)
LOG_FILE=/var/log/linkat-installer.log
SERVER=http://download-linkat.xtec.cat/distribution/linkat-edu-16.04

echo "########## START ###########" >> $LOG_FILE
date >> $LOG_FILE

sudo dpkg -s linkat-base
if [ $? = 0 ] ; then
	echo "ERROR: El paquet linkat-base ja es troba instal·lat, el programa s'aturarà" >> $LOG_FILE
	echo "######## END #########" >> $LOG_FILE
	exit 1
fi

cd $TMPDIR


## Descarregant la clau pública del repositori de la Linkat 
## Comprovant la connexió a Internet
wget $SERVER/pubkey-linkat16.gpg
if [ $? = 0 ] ; then
	echo "OK: Clau del repositori descarregada" >> $LOG_FILE
else
	echo "ERROR: S'ha produit un error descarregant la clau de la Linkat" >> $LOG_FILE
	echo "Comproveu la vostra connexió a Internet" >> $LOG_FILE
	exit 1
fi

## Descarregant el fitxer de configuració del repositori Linkat
wget $SERVER/linkat-repo-16.04.list
if [ $? = 0 ] ; then
	echo "OK: Fitxer de configuració decarregat" >> $LOG_FILE
else
	echo "ERROR: S'ha produit un error descarregant linkat-repo.list" >> $LOG_FILE
        echo "Comproveu la vostra connexió a Internet" >> $LOG_FILE
        exit 1
fi

## Afegint clau del repositori
if [ -f pubkey-linkat16.gpg ] ; then
	sudo apt-key add pubkey-linkat16.gpg
	echo "OK: Clau afegida" >> $LOG_FILE
else
	echo "ERROR: No s'ha trobat la clau pública de la Linkat" >> $LOG_FILE
	exit 1
fi

## Afegint repositori Linkat
if [ -f linkat-repo-16.04.list ] ; then
	sudo cp linkat-repo-16.04.list /etc/apt/sources.list.d/
	echo "OK: Repositori afegit" >> $LOG_FILE
else
	echo "ERROR: No s'ha trobat la configuració del repositori Linkat" >> $LOG_FILE
        exit 1
fi

## Actualitzant els repositoris
sudo apt-get update
if [ $? = 0 ] ; then
	echo "OK: Repositoris actualitzats" >> $LOG_FILE
else
	echo "ERROR: S'ha produit un error actualizant els repositoris" >> $LOG_FILE
	exit 1
fi

## Instal·lant el paquet linkat-base
sudo apt-get install linkat-base
if [ $? = 0  ] ; then
	echo "OK: Paquet instal·lat" >> $LOG_FILE
else
	echo "ERROR: S'ha produit un error instal·lant els paquets" >> $LOG_FILE
        exit 1
fi

## Esborrant els temporals
sudo rm -rf $TMPDIR
if [ $? = 0 ] ; then
	echo "OK: Temporals esborrats"  >> $LOG_FILE
else
	echo "ERROR: No s'ha pogut eliminar els temporals"  >> $LOG_FILE
fi

echo "Instal·lació finalitzada" >> $LOG_FILE
date >> $LOG_FILE
echo "######## END #########" >> $LOG_FILE

exit 0
